==> seedsui-react-2.7.4.tgz: package/es/InputLocation/InputLocation.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import InputText from './../InputText';
import Bridge from './../Bridge';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var InputLocation = (_temp = _class = function (_Component) {
  _inherits(InputLocation, _Component);

  function InputLocation(props) {
    _classCallCheck(this, InputLocation);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (event, value) {
      var _this$props = _this.props,
          valueBindProp = _this$props.valueBindProp,
          locationingText = _this$props.locationingText,
          onChange = _this$props.onChange,
          onClick = _this$props.onClick;

      var e = event.nativeEvent;
      if (onClick) onClick(e, value);
      if (_this.$input.value === locationingText) return;
      // 定位中...
      if (!valueBindProp) {
        _this.$input.value = locationingText;
      }
      Bridge.getLocation({
        type: 'gcj02',
        success: function success(data) {
          // 客户端中不需要再getAddress
          if (data.address) {
            // 赋值
            if (!valueBindProp) _this.$input.value = data.address;
            if (onChange) onChange(e, data.address, data);
            return;
          }
          Bridge.getAddress({ // 只支持gcj02
            latitude: data.latitude,
            longitude: data.longitude,
            success: function success(addrs) {
              // 赋值
              if (!valueBindProp) _this.$input.value = addrs.address;
              if (onChange) onChange(e, addrs.address, data);
            },
            fail: function fail(res) {
              // 赋值
              if (!valueBindProp) _this.$input.value = '';
              if (onChange) onChange(e, '', data);
              // 提示获取地址失败
              Bridge.showToast(res.errMsg, { mask: false });
            }
          });
        },
        fail: function fail(res) {
          // 赋值
          if (!valueBindProp) _this.$input.value = '';
          if (onChange) onChange(e, '', null);
          // 提示定位失败
          Bridge.showToast(res.errMsg, { mask: false });
        }
      });
    };

    return _this;
  }

  InputLocation.prototype.componentDidMount = function componentDidMount() {
    this.$el = null;
    this.$input = null;
    if (this.refs.$ComponentInputText && this.refs.$ComponentInputText.$el && this.refs.$ComponentInputText.$input) {
      this.$el = this.refs.$ComponentInputText.$el;
      this.$input = this.refs.$ComponentInputText.$input;
    }
  };

  InputLocation.prototype.render = function render() {
    var _props = this.props,
        locationingText = _props.locationingText,
        onChange = _props.onChange,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['locationingText', 'onChange', 'onClick']);

    return React.createElement(InputText, _extends({ ref: '$ComponentInputText' }, others, { readOnly: true, onClick: this.onClick }));
  };

  return InputLocation;
}(Component), _class.defaultProps = {
  locationingText: window._seeds_lang['location'] || '定位中...'
}, _temp);
export { InputLocation as default };
InputLocation.propTypes = process.env.NODE_ENV !== "production" ? {
  locationingText: PropTypes.string,
  onClick: PropTypes.func,
  onChange: PropTypes.func
} : {};

==> seedsui-react-2.7.9.tgz: package/es/InputLocation/InputLocation.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import InputText from './../InputText';
import Bridge from './../Bridge';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var InputLocation = (_temp = _class = function (_Component) {
  _inherits(InputLocation, _Component);

  function InputLocation(props) {
    _classCallCheck(this, InputLocation);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (event, value) {
      var _this$props = _this.props,
          locationingValue = _this$props.locationingValue,
          failedValue = _this$props.failedValue,
          onChange = _this$props.onChange,
          onClick = _this$props.onClick;

      var e = event.nativeEvent;
      if (onClick) onClick(e, value);
      if (_this.$input.value === locationingValue) return;
      // 定位中...
      _this.$input.value = locationingValue;
      Bridge.getLocation({
        type: 'gcj02',
        success: function success(data) {
          // 客户端中不需要再getAddress
          if (data.address) {
            // 赋值
            if (onChange) {
              onChange(e, data.address, data);
              _this.$input.value = data.address;
            }
            return;
          }
          Bridge.getAddress({ // 只支持gcj02
            latitude: data.latitude,
            longitude: data.longitude,
            success: function success(addrs) {
              // 赋值
              if (onChange) onChange(e, addrs.address, data);
              _this.$input.value = addrs.address;
            },
            fail: function fail(res) {
              // 赋值
              if (onChange) onChange(e, '', data);
              _this.$input.value = failedValue;
              // 提示获取地址失败
              Bridge.showToast(res.errMsg, { mask: false });
            }
          });
        },
        fail: function fail(res) {
          // 赋值
          if (onChange) onChange(e, '', null);
          _this.$input.value = failedValue;
          // 提示定位失败
          Bridge.showToast(res.errMsg, { mask: false });
        }
      });
    };

    return _this;
  }

  InputLocation.prototype.componentDidMount = function componentDidMount() {
    this.$el = null;
    this.$input = null;
    if (this.refs.$ComponentInputText && this.refs.$ComponentInputText.$el && this.refs.$ComponentInputText.$input) {
      this.$el = this.refs.$ComponentInputText.$el;
      this.$input = this.refs.$ComponentInputText.$input;
    }
  };

  InputLocation.prototype.render = function render() {
    var _props = this.props,
        locationingValue = _props.locationingValue,
        failedValue = _props.failedValue,
        onChange = _props.onChange,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['locationingValue', 'failedValue', 'onChange', 'onClick']);

    return React.createElement(InputText, _extends({ ref: '$ComponentInputText' }, others, { readOnly: true, onClick: this.onClick }));
  };

  return InputLocation;
}(Component), _class.defaultProps = {
  locationingValue: window._seeds_lang['location'] || '定位中...',
  failedValue: window._seeds_lang['hint_location_failed'] || '定位失败, 请检查定位权限是否开启'
}, _temp);
export { InputLocation as default };
InputLocation.propTypes = process.env.NODE_ENV !== "production" ? {
  locationingValue: PropTypes.string,
  failedValue: PropTypes.string,
  onClick: PropTypes.func,
  onChange: PropTypes.func
} : {};
